@@ -36,5 +36,4 @@ class ControllerClient(MessageClient):
     def set_behavior(self, behavior: int) -> bool:
         return self.send_request(Message("set_behavior", behavior)).get_body(bool)
 
-    def joystick(self) -> bool:
-        return self.send_request(Message("joystick")).get_body(bool)
+
